//===-- X86AsmPrinter.h - Convert X86 LLVM code to Intel assembly ---------===//
//
//                     The LLVM Compiler Infrastructure
//
// This file was developed by the LLVM research group and is distributed under
// the University of Illinois Open Source License. See LICENSE.TXT for details.
//
//===----------------------------------------------------------------------===//
//
// This file the shared super class printer that converts from our internal
// representation of machine-dependent LLVM code to Intel and AT&T format
// assembly language.
// This printer is the output mechanism used by `llc' and `lli
// -print-machineinstrs' on X86.
//
//===----------------------------------------------------------------------===//

namespace llvm {
  namespace X86 {
    extern Statistic<> EmittedInsts;

    enum AsmWriterFlavor { att, intel };

    struct X86SharedAsmPrinter : public AsmPrinter {
      X86SharedAsmPrinter(std::ostream &O, TargetMachine &TM)
        : AsmPrinter(O, TM), forCygwin(false), forDarwin(false)
    	{ }

      bool doInitialization(Module &M);
      void printConstantPool(MachineConstantPool *MCP);
      bool doFinalization(Module &M);

      static bool isScale(const MachineOperand &MO);
      static bool isMem(const MachineInstr *MI, unsigned Op);
      static void SwitchSection(std::ostream &OS, std::string &CurSection,
    							const char *NewSection);

      bool forCygwin;
      bool forDarwin;
    };
  }
}
